==> inti-wp-1.0.4-930059.tar: src/ConfigProvider.php <==
<?php
declare(strict_types=1);

namespace Inti\Wp;

use Inti\Wp\Plugin\Service\PluginManager;
use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;

/**
 * Class ConfigProvider
 *
 * @package Inti\Wp
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return (new ConfigAggregator([
            \Inti\App\ConfigProvider::class,
            \Inti\Db\ConfigProvider::class,

            Middleware\ConfigProvider::class,
            Plugin\ConfigProvider::class,

            new ArrayProvider([
                'wp' => [
                    'assets' => [
                        'manifest_path' => 'public/dist/manifest.json',
                        'dequeue' => [],
                    ],

                    'plugins' => [
                        Plugin\Assets::class,
                        Plugin\DefaultFilters::class,
                        Plugin\ResourceHints::class,
                    ],
                ],

                PluginManager::class => [
                    'factories' => [
                        Plugin\Assets::class => Plugin\Factory\AssetsFactory::class,
                    ],
                ],

                'dependencies' => [
                    'factories' => [
                        'assets' => Container\AssetManifestFactory::class,
                    ],
                ],
            ])
        ]))->getMergedConfig();
    }
}

==> inti-wp-1.0.9-3212a0.tar: src/ConfigProvider.php <==
<?php
declare(strict_types=1);

namespace Inti\Wp;

use Inti\Wp\Plugin\Service\PluginManager;
use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;

/**
 * Class ConfigProvider
 *
 * @package Inti\Wp
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return (new ConfigAggregator([
            \Inti\Db\ConfigProvider::class,
            \Inti\Elementor\ConfigProvider::class,
            \Inti\Filter\ConfigProvider::class,
            \Inti\Media\ConfigProvider::class,
            \Inti\Provider\ConfigProvider::class,

            Middleware\ConfigProvider::class,
            Plugin\ConfigProvider::class,
            Provider\ConfigProvider::class,

            new ArrayProvider([
                'wp' => [
                    'assets' => [
                        'manifest_path' => 'public/dist/manifest.json',
                        'dequeue' => [],
                    ],

                    'plugins' => [
                        Plugin\Assets::class,
                        Plugin\DefaultFilters::class,
                        Plugin\ResourceHints::class,
                    ],
                ],

                PluginManager::class => [
                    'factories' => [
                        Plugin\Assets::class => Plugin\Factory\AssetsFactory::class,
                    ],
                ],

                'dependencies' => [
                    'factories' => [
                        'assets' => Container\AssetManifestFactory::class,
                    ],
                ],
            ])
        ]))->getMergedConfig();
    }
}
